@@ -9,7 +9,6 @@ class Nonces(object):
     ApplePayAmEx = "fake-apple-pay-amex-nonce"
     AbstractTransactable = "fake-abstract-transactable-nonce"
     Europe = "fake-europe-bank-account-nonce"
-    Coinbase = "fake-coinbase-nonce"
     AndroidPayCard = "fake-android-pay-nonce"
     AndroidPayCardDiscover = "fake-android-pay-discover-nonce"
     AndroidPayCardVisa = "fake-android-pay-visa-nonce"
@@ -17,7 +16,22 @@ class Nonces(object):
     AndroidPayCardAmEx = "fake-android-pay-amex-nonce"
     AmexExpressCheckoutCard = "fake-amex-express-checkout-nonce"
     VenmoAccount = "fake-venmo-account-nonce"
+    VenmoAccountTokenIssuanceError = "fake-token-issuance-error-venmo-account-nonce"
     ThreeDSecureVisaFullAuthentication = "fake-three-d-secure-visa-full-authentication-nonce"
+    ThreeDSecureVisaLookupTimeout = "fake-three-d-secure-visa-lookup-timeout-nonce"
+    ThreeDSecureVisaFailedSignature = "fake-three-d-secure-visa-failed-signature-nonce"
+    ThreeDSecureVisaFailedAuthentication = "fake-three-d-secure-visa-failed-authentication-nonce"
+    ThreeDSecureVisaAttemptsNonParticipating = "fake-three-d-secure-visa-attempts-non-participating-nonce"
+    ThreeDSecureVisaNoteEnrolled = "fake-three-d-secure-visa-not-enrolled-nonce"
+    ThreeDSecureVisaUnavailable = "fake-three-d-secure-visa-unavailable-nonce"
+    ThreeDSecureVisaMPILookupError = "fake-three-d-secure-visa-mpi-lookup-error-nonce"
+    ThreeDSecureVisaMPIAuthenticateError = "fake-three-d-secure-visa-mpi-authenticate-error-nonce"
+    ThreeDSecureVisaAuthenticationUnavailable = "fake-three-d-secure-visa-authentication-unavailable-nonce"
+    ThreeDSecureVisaBypassedAuthentication = "fake-three-d-secure-visa-bypassed-authentication-nonce"
+    ThreeDSecureTwoVisaSuccessfulFrictionlessAuthentication = "fake-three-d-secure-two-visa-successful-frictionless-authentication-nonce"
+    ThreeDSecureTwoVisaSuccessfulStepUpAuthentication = "fake-three-d-secure-two-visa-successful-step-up-authentication-nonce"
+    ThreeDSecureTwoVisaErrorOnLookup = "fake-three-d-secure-two-visa-error-on-lookup-nonce"
+    ThreeDSecureTwoVisaTimeoutOnLookup = "fake-three-d-secure-two-visa-timeout-on-lookup-nonce"
     TransactableVisa = "fake-valid-visa-nonce"
     TransactableAmEx = "fake-valid-amex-nonce"
     TransactableMasterCard = "fake-valid-mastercard-nonce"
